function base64_decode (s) {
	var base64chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/'.split("");
	var base64inv = [];

	for (var i = 0; i < base64chars.length; i++) {
		base64inv[base64chars[i]] = i;
	}

	// replace any incoming padding with a zero pad (the 'A' character is zero)
	var p = (s.charAt(s.length-1) == '=' ? (s.charAt(s.length-2) == '='
                                        ? 'AA' : 'A') : "");
	var r = "";
	s = s.substr(0, s.length - p.length) + p;

	// remove/ignore any characters not in the base64 characters list -- particularly newlines
	s = s.replace(new RegExp('[^'+base64chars.join("")+']', 'g'), "");

	// increment over the length of this encrypted string, four characters at a time
	for (var c = 0; c < s.length; c += 4) {

		// each of these four characters represents a 6-bit index in the base64 characters list
		//  which, when concatenated, will give the 24-bit number for the original 3 characters
		var n = (base64inv[s.charAt(c)] << 18) + base64inv[s.charAt(c+3)] +
		        (base64inv[s.charAt(c+1)] << 12) + (base64inv[s.charAt(c+2)] << 6);

		// split the 24-bit number into the original three 8-bit (ASCII) characters
		r += String.fromCharCode((n >>> 16) & 255, (n >>> 8) & 255, n & 255);

		// remove any zero pad that was added to make this a multiple of 24 bits
	}
	return r.substring(0, r.length - p.length);
}

function decodeURL(url) {
	var address = url;
	var index = address.indexOf("%");
	var percentIndex = -2;
	var foundPercent = false;

	while(index !== -1) {
		var num = address.substring(index+1, index+3);

		if(num === "25") {
			foundPercent = true;
			percentIndex = index;
		}

		address = address.substring(0, index) + String.fromCharCode(parseInt(num, 16)) + address.substring(index + 3);

		if(foundPercent)
			index = address.indexOf("%", percentIndex + 1);
		else
			index = address.indexOf("%");
	}
	return address;
}


function propFind(address) {
	try {
		if(address === null)
			address = gVars.base_url + gVars.curr_dir;

		var req = new XMLHttpRequest();
		req.open("Propfind", address, false);
		req.setRequestHeader("Content-Type", 'application/xml; charset="utf-8"');
		req.setRequestHeader("Depth", "1");
		req.send('<?xml version="1.0" encoding="utf-8" ?>\n<D:propfind xmlns:D="DAV:">\n<D:allprop/>\n</D:propfind>');

		if(req.status === 200 || req.status === 207)
			return req.responseXML;
		else {
			alert("Invalid response from server.\nServer Response: " + req.status + " " + req.statusText);
			return null;
		}
	}
	catch(err) {
		alert("propFind: " + err);
	}
}

function checkForDav(address) {
	try {
		var req = new XMLHttpRequest();
		req.open("OPTIONS", address, false);

		try {
			req.send("");
		}
		catch(e) {
			return -1;
		}

		var dav = req.getResponseHeader("Dav");

		try {
			C = req.channel;
			C = C.QueryInterface(Components.interfaces.nsIHttpChannel);
			var read  = C.getRequestHeader("Authorization");

			if (read.substring(0,4) === "Basic") {
				uNameAndPass64  = read.substring(read.indexOf(" "), read.length);
				var uNameAndPass = base64_decode(uNameAndPass64);
				gVars.uName = uNameAndPass.substring(0, uNameAndPass.indexOf(":"))
			        }
			        else
				        gVars.uName = "";
		}
		catch (e) {
			gVars.uName = "";
		}

		if(dav !== null) {
			if(dav.indexOf("2") !== -1)
				return 2;
			else
				return 1;
		}
		else
			return -1;
	}
	catch(e) {
		alert("checkForDAV:  " + e);
		return -1;
	}
}
